# Static files for testing

* [**optimade_response.json**](optimade_response.json)
  A mock OPTIMADE response to the generic request: `<base URL>/v1/structures?filter=elements HAS ALL "Si","O"&sort=nelements`.
  The actual request was performed against the MaterialsCloud database "optimade-sample": [https://aiida.materialscloud.org/optimade-sample/optimade/v1/structures?filter=elements HAS ALL "Si","O"&sort=nelements&page_limit=2](https://aiida.materialscloud.org/optimade-sample/optimade/v1/structures?filter=elementsHAS%20ALL%20%22Si%22,%22O%22&sort=nelements&page_limit=2)
